epistasis\.models package
=========================

See subpackages for specific models.

.. toctree::

    epistasis.models.linear
    epistasis.models.nonlinear

epistasis\.models\.base module
------------------------------

.. automodule:: epistasis.models.base
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.classifiers module
-------------------------------------

.. automodule:: epistasis.models.classifiers
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.ensemble module
----------------------------------

.. automodule:: epistasis.models.ensemble
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.pipeline module
----------------------------------

.. automodule:: epistasis.models.pipeline
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.utils module
-------------------------------

.. automodule:: epistasis.models.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: epistasis.models
    :members:
    :undoc-members:
    :show-inheritance:
